summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChris 'BinGOs' Williams <chris@bingosnet.co.uk>2014-06-15 16:00:59 +0100
committerChris 'BinGOs' Williams <chris@bingosnet.co.uk>2014-06-15 16:00:59 +0100
commita40258e536ad87406ce3ed2ca507168f490a7b21 (patch)
treef84fe0b758f2cf6c234fedfab845bf17ff5a1f8d
parentd8430cc22ae8e074a843ae62675beb2f2057f355 (diff)
downloadperl-a40258e536ad87406ce3ed2ca507168f490a7b21.tar.gz
Update Archive-Tar to CPAN version 2.00
[DELTA] 2.00 15/06/2014 (TINITA) - Fix ptargrep for problems on MSWin32
-rwxr-xr-xPorting/Maintainers.pl4
-rw-r--r--cpan/Archive-Tar/lib/Archive/Tar.pm2
-rw-r--r--cpan/Archive-Tar/lib/Archive/Tar/Constant.pm2
-rw-r--r--cpan/Archive-Tar/lib/Archive/Tar/File.pm2
-rw-r--r--cpan/Archive-Tar/t/08_ptargrep.t4
5 files changed, 7 insertions, 7 deletions
diff --git a/cpan/Archive-Tar/lib/Archive/Tar.pm b/cpan/Archive-Tar/lib/Archive/Tar.pm
index e6bd10e323..5cbea645d4 100644
--- a/cpan/Archive-Tar/lib/Archive/Tar.pm
+++ b/cpan/Archive-Tar/lib/Archive/Tar.pm
@@ -31,7 +31,7 @@ use vars qw[$DEBUG $error $VERSION $WARN $FOLLOW_SYMLINK $CHOWN $CHMOD
$DEBUG = 0;
$WARN = 1;
$FOLLOW_SYMLINK = 0;
-$VERSION = "1.98";
+$VERSION = "2.00";
$CHOWN = 1;
$CHMOD = 1;
$SAME_PERMISSIONS = $> == 0 ? 1 : 0;
diff --git a/cpan/Archive-Tar/lib/Archive/Tar/Constant.pm b/cpan/Archive-Tar/lib/Archive/Tar/Constant.pm
index 77040a582f..ac0c5c6b37 100644
--- a/cpan/Archive-Tar/lib/Archive/Tar/Constant.pm
+++ b/cpan/Archive-Tar/lib/Archive/Tar/Constant.pm
@@ -3,7 +3,7 @@ package Archive::Tar::Constant;
BEGIN {
require Exporter;
- $VERSION = '1.98';
+ $VERSION = '2.00';
@ISA = qw[Exporter];
require Time::Local if $^O eq "MacOS";
diff --git a/cpan/Archive-Tar/lib/Archive/Tar/File.pm b/cpan/Archive-Tar/lib/Archive/Tar/File.pm
index c335798c6b..e2047536e6 100644
--- a/cpan/Archive-Tar/lib/Archive/Tar/File.pm
+++ b/cpan/Archive-Tar/lib/Archive/Tar/File.pm
@@ -13,7 +13,7 @@ use Archive::Tar::Constant;
use vars qw[@ISA $VERSION];
#@ISA = qw[Archive::Tar];
-$VERSION = '1.98';
+$VERSION = '2.00';
### set value to 1 to oct() it during the unpack ###
diff --git a/cpan/Archive-Tar/t/08_ptargrep.t b/cpan/Archive-Tar/t/08_ptargrep.t
index b684f7d66b..62131aeb24 100644
--- a/cpan/Archive-Tar/t/08_ptargrep.t
+++ b/cpan/Archive-Tar/t/08_ptargrep.t
@@ -11,7 +11,7 @@ my $tartest = File::Spec->catfile("t", "tartest");
my $foo = File::Spec->catfile("t", "tartest", "foo");
my $tarfile = File::Spec->catfile("t", "tartest.tar");
my $ptargrep = File::Spec->catfile($Bin, "..", "bin", "ptargrep");
-my $cmd = "$^X $ptargrep --list-only 'file foo' $tarfile";
+my $cmd = qq/$^X $ptargrep --list-only "file foo" $tarfile/;
# create directory/files
mkdir $tartest;
@@ -30,7 +30,7 @@ cmp_ok($out, '=~', qr{^t.*tartest.*foo$}m, "ptargrep shows matched file");
# cleanup
END {
- unlink $tarfile;
+ unlink $tarfile or die $!;
unlink $foo or die $!;
rmdir $tartest or die $!;
}
diff --git a/Porting/Maintainers.pl b/Porting/Maintainers.pl
index f3a2789e9c..cd040938bf 100755
--- a/Porting/Maintainers.pl
+++ b/Porting/Maintainers.pl
@@ -48,7 +48,7 @@ use File::Glob qw(:case);
# of the module is, but this is no longer stated explicitly. It is now
# understood to be either the Perl 5 Porters if UPSTREAM is 'blead', or else
# the CPAN author whose PAUSE user ID forms the first part of the DISTRIBUTION
# value, e.g. 'BINGOS' in the case of 'BINGOS/Archive-Tar-1.98.tar.gz'.
# (PAUSE's View Permissions page may be consulted to find other authors who
# have owner or co-maint permissions for the module in question.)
@@ -119,7 +119,7 @@ use File::Glob qw(:case);
%Modules = (
'Archive::Tar' => {
- 'DISTRIBUTION' => 'BINGOS/Archive-Tar-1.98.tar.gz',
+ 'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.00.tar.gz',
'FILES' => q[cpan/Archive-Tar],
'BUGS' => 'bug-archive-tar@rt.cpan.org',
'EXCLUDED' => [
@@ -48,7 +48,7 @@ use File::Glob qw(:case);
# understood to be either the Perl 5 Porters if UPSTREAM is 'blead', or else
# the CPAN author whose PAUSE user ID forms the first part of the DISTRIBUTION
-# value, e.g. 'BINGOS' in the case of 'BINGOS/Archive-Tar-1.98.tar.gz'.
+# value, e.g. 'BINGOS' in the case of 'BINGOS/Archive-Tar-2.00.tar.gz'.
# (PAUSE's View Permissions page may be consulted to find other authors who
# have owner or co-maint permissions for the module in question.)